@@ -131,7 +131,7 @@ var NagVisObject = Base.extend({
 
         // The line labels need a) the line added to DOM and b) the label added
         // to the dom before being able to calculate the correct coordinates
-        // needed in place().   
+        // needed in place().
         if (this.conf.type == 'line' || this.conf.view_type == 'line')
             for (var i = 0; i < this.elements.length; i++)
                 this.elements[i].place();
@@ -334,32 +334,25 @@ var NagVisObject = Base.extend({
             addZoom = true;
 
         var coord = 0;
+
         if(!isRelativeCoord(val)) {
             coord = parseInt(val);
         } else {
-            // This must be an object id. Is there an offset given?
-            if(val.search('%') !== -1) {
-                var parts     = val.split('%');
-                var objectId  = parts[0];
-                var offset    = parts[1];
-                var refObj    = getMapObjByDomObjId(objectId);
-                if (refObj) {
-                    coord = parseFloat(refObj.parseCoord(refObj.conf[dir], dir, false));
-                    if (addZoom)
-                        coord = addZoomFactor(coord, true);
+            var parts     = val.split('%');
+            var objectId  = parts[0];
+            var offset    = parts[1];
+            var refObj    = getMapObjByDomObjId(objectId);
+            if (refObj) {
+                coord = parseFloat(refObj.parseCoord(refObj.conf[dir], dir, false));
+                if (addZoom)
+                    coord = addZoomFactor(coord, true);
 
-                    if (addZoom)
-                        coord += addZoomFactor(parseFloat(offset), false);
-                    else
-                        coord += parseFloat(offset);
+                if (addZoom)
+                    coord += addZoomFactor(parseFloat(offset), false);
+                else
+                    coord += parseFloat(offset);
 
-                    return coord;
-                }
-            } else {
-                // Only an object id. Get the coordinate and return it
-                var refObj = getMapObjByDomObjId(val);
-                if(refObj)
-                    coord = parseInt(refObj.parseCoord(refObj.conf[dir], dir, false));
+                return coord;
             }
         }
 
